summaryrefslogtreecommitdiffstats
path: root/libkpgp/kpgpui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkpgp/kpgpui.cpp')
-rw-r--r--libkpgp/kpgpui.cpp62
1 files changed, 31 insertions, 31 deletions
diff --git a/libkpgp/kpgpui.cpp b/libkpgp/kpgpui.cpp
index ea126251..c9288b01 100644
--- a/libkpgp/kpgpui.cpp
+++ b/libkpgp/kpgpui.cpp
@@ -24,10 +24,10 @@
#include <tqwhatsthis.h>
#include <tqtooltip.h>
#include <tqapplication.h>
-#include <textcodec.h>
+#include <tqtextcodec.h>
#include <tqdatetime.h>
#include <tqpixmap.h>
-#include <layout.h>
+#include <tqlayout.h>
#include <tqtimer.h>
#include <tqpopupmenu.h>
#include <tqregexp.h>
@@ -76,7 +76,7 @@ PassphraseDialog::PassphraseDialog( TQWidget *parent,
if (keyID.isNull())
label = new TQLabel(i18n("Please enter your OpenPGP passphrase:"),rightArea);
else
- label = new TQLabel(i18n("Please enter the OpenPGP passphrase for\n\"%1\":").arg(keyID),
+ label = new TQLabel(i18n("Please enter the OpenPGP passphrase for\n\"%1\":").tqarg(keyID),
rightArea);
lineedit = new KPasswordEdit( rightArea );
lineedit->setEchoMode(TQLineEdit::Password);
@@ -115,7 +115,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
TQVBoxLayout *topLayout = new TQVBoxLayout( this, 0, KDialog::spacingHint() );
group = new TQVGroupBox( i18n("Warning"), this );
- group->layout()->setSpacing( KDialog::spacingHint() );
+ group->tqlayout()->setSpacing( KDialog::spacingHint() );
// (mmutz) work around TQt label bug in 3.0.0 (and possibly later):
// 1. Don't use rich text: No <qt><b>...</b></qt>
label = new TQLabel( i18n("Please check if encryption really "
@@ -126,13 +126,13 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
labelFont.setBold( true );
label->setFont( labelFont );
// 3. and activate wordwarp:
- label->setAlignment( AlignLeft|WordBreak );
+ label->tqsetAlignment( AlignLeft|WordBreak );
// end; to remove the workaround, add <qt><b>..</b></qt> around the
// text and remove lines TQFont... -> label->setAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
- group->layout()->setSpacing( KDialog::spacingHint() );
+ group->tqlayout()->setSpacing( KDialog::spacingHint() );
TQHBox * hbox = new TQHBox( group );
label = new TQLabel( i18n("Select encryption tool to &use:"), hbox );
@@ -153,7 +153,7 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
topLayout->addWidget( group );
mpOptionsGroupBox = new TQVGroupBox( i18n("Options"), this );
- mpOptionsGroupBox->layout()->setSpacing( KDialog::spacingHint() );
+ mpOptionsGroupBox->tqlayout()->setSpacing( KDialog::spacingHint() );
storePass = new TQCheckBox( i18n("&Keep passphrase in memory"),
mpOptionsGroupBox );
connect( storePass, TQT_SIGNAL( toggled( bool ) ),
@@ -461,7 +461,7 @@ void KeySelectionDialog::initKeylist( const KeyList& keyList,
childItem = new TQListViewItem( primaryUserID, "",
i18n( "Fingerprint: %1" )
- .arg( beautifyFingerprint( (*it)->primaryFingerprint() ) ) );
+ .tqarg( beautifyFingerprint( (*it)->primaryFingerprint() ) ) );
if( primaryUserID->isSelected() && mListView->isMultiSelection() ) {
mListView->setSelected( childItem, true );
}
@@ -543,15 +543,15 @@ TQString KeySelectionDialog::keyInfo( const Kpgp::Key *key ) const
if( remark.isEmpty() ) {
return " " + i18n("creation date and status of an OpenPGP key",
"Creation date: %1, Status: %2")
- .arg( KGlobal::locale()->formatDate( dt.date(), true ) )
- .arg( status );
+ .tqarg( KGlobal::locale()->formatDate( dt.date(), true ) )
+ .tqarg( status );
}
else {
return " " + i18n("creation date, status and remark of an OpenPGP key",
"Creation date: %1, Status: %2 (%3)")
- .arg( KGlobal::locale()->formatDate( dt.date(), true ) )
- .arg( status )
- .arg( remark );
+ .tqarg( KGlobal::locale()->formatDate( dt.date(), true ) )
+ .tqarg( status )
+ .tqarg( remark );
}
}
@@ -1014,7 +1014,7 @@ bool KeySelectionDialog::checkKeys( const TQValueList<TQListViewItem*>& keys ) c
++it ) {
kdDebug(5100) << "Checking key 0x" << getKeyId( *it ) << "...\n";
pProgressDlg->setLabel( i18n("Checking key 0x%1...")
- .arg( TQString( getKeyId( *it ) ) ) );
+ .tqarg( TQString( getKeyId( *it ) ) ) );
kapp->processEvents();
keysAllowed = keysAllowed && ( -1 != keyAdmissibility( *it, AllowExpensiveTrustCheck ) );
pProgressDlg->progressBar()->advance( 1 );
@@ -1176,7 +1176,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
// the button to unset any key:
mEraseButton = new TQPushButton( this );
mEraseButton->setAutoDefault( false );
- mEraseButton->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
+ mEraseButton->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum,
TQSizePolicy::Minimum ) );
mEraseButton->setPixmap( SmallIcon( "clear_left" ) );
TQToolTip::add( mEraseButton, i18n("Clear") );
@@ -1192,7 +1192,7 @@ KeyRequester::KeyRequester( TQWidget * parent, bool multipleKeys,
connect( mEraseButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotEraseButtonClicked()) );
connect( mDialogButton, TQT_SIGNAL(clicked()), TQT_SLOT(slotDialogButtonClicked()) );
- setSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
+ tqsetSizePolicy( TQSizePolicy( TQSizePolicy::MinimumExpanding,
TQSizePolicy::Fixed ) );
}
@@ -1480,21 +1480,21 @@ KeyApprovalDialog::KeyApprovalDialog( const TQStringList& addresses,
// calculate the optimal width for the dialog
int dialogWidth = marginHint()
+ sv->frameWidth()
- + bigvbox->sizeHint().width()
- + sv->verticalScrollBar()->sizeHint().width()
+ + bigvbox->tqsizeHint().width()
+ + sv->verticalScrollBar()->tqsizeHint().width()
+ sv->frameWidth()
+ marginHint()
+ 2;
// calculate the optimal height for the dialog
int dialogHeight = marginHint()
- + label->sizeHint().height()
+ + label->tqsizeHint().height()
+ topLayout->spacing()
+ sv->frameWidth()
- + bigvbox->sizeHint().height()
- + sv->horizontalScrollBar()->sizeHint().height()
+ + bigvbox->tqsizeHint().height()
+ + sv->horizontalScrollBar()->tqsizeHint().height()
+ sv->frameWidth()
+ topLayout->spacing()
- + actionButton( KDialogBase::Cancel )->sizeHint().height()
+ + actionButton( KDialogBase::Cancel )->tqsizeHint().height()
+ marginHint()
+ 2;
// don't make the dialog too large
@@ -1543,7 +1543,7 @@ KeyApprovalDialog::slotChangeEncryptionKey( int nr )
"Select the key(s) which should "
"be used to encrypt the message "
"for\n%1")
- .arg( mAddressLabels[nr-1]->text() ),
+ .tqarg( mAddressLabels[nr-1]->text() ),
keyIds,
mAddressLabels[nr-1]->text(),
mAllowedKeys );
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
mEditBox->setReadOnly(true);
topLayout->addWidget( mEditBox, 10 );
- TQString unicodeText;
+ TQString tqunicodeText;
if (charset.isEmpty())
- unicodeText = TQString::fromLocal8Bit(text.data());
+ tqunicodeText = TQString::fromLocal8Bit(text.data());
else {
bool ok=true;
TQTextCodec *codec = KGlobal::charsets()->codecForName(charset, ok);
if(!ok)
- unicodeText = TQString::fromLocal8Bit(text.data());
+ tqunicodeText = TQString::fromLocal8Bit(text.data());
else
- unicodeText = codec->toUnicode(text.data(), text.length());
+ tqunicodeText = codec->toUnicode(text.data(), text.length());
}
- mEditBox->setText(unicodeText);
+ mEditBox->setText(tqunicodeText);
setMinimumSize();
}
void CipherTextDialog::setMinimumSize()
{
// this seems to force a layout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )
(void) mEditBox->paragraphRect( i );
@@ -1670,7 +1670,7 @@ void CipherTextDialog::setMinimumSize()
gc.readBoolEntry("XineramaPlacementEnabled", true)) {
maxWidth = TQApplication::desktop()->screenGeometry(TQApplication::desktop()->screenNumber(parentWidget())).width()-100;
} else {
- maxWidth = TQApplication::desktop()->geometry().width()-100;
+ maxWidth = TQApplication::desktop()->tqgeometry().width()-100;
}
#endif
@@ -126,13 +126,13 @@ Config::Config( TQWidget *parent, const char *name, bool encrypt )
// end; to remove the workaround, add <qt><b>..</b></qt> around the
- // text and remove lines TQFont... -> label->setAlignment(...).
+ // text and remove lines TQFont... -> label->tqsetAlignment(...).
topLayout->addWidget( group );
group = new TQVGroupBox( i18n("Encryption Tool"), this );
@@ -1630,26 +1630,26 @@ CipherTextDialog::CipherTextDialog( const TQCString & text,
void CipherTextDialog::setMinimumSize()
{
- // this seems to force a layout of the entire document, so we get a
+ // this seems to force a tqlayout of the entire document, so we get a
// a proper contentsWidth(). Is there a better way?
for ( int i = 0; i < mEditBox->paragraphs(); i++ )